@@ -1,4 +1,5 @@
 from typing import Optional, Tuple
+from httpx import _types
 
 Url = str
 ServiceName = str
@@ -8,6 +9,7 @@ Version = Optional[str]
 Service = Tuple[str, Version]
 
 Path = str
+Proxies = _types.ProxiesTypes
 
 try:
     from typing import Literal
